@@ -30,7 +30,7 @@
 
 G_BEGIN_DECLS
 
-#define GNOME_DB_CONDITION_TYPE          (gnome_db_condition_get_type())
+#define GNOME_DB_TYPE_CONDITION          (gnome_db_condition_get_type())
 #define GNOME_DB_CONDITION(obj)          G_TYPE_CHECK_INSTANCE_CAST (obj, gnome_db_condition_get_type(), GnomeDbCondition)
 #define GNOME_DB_CONDITION_CLASS(klass)  G_TYPE_CHECK_CLASS_CAST (klass, gnome_db_condition_get_type (), GnomeDbConditionClass)
 #define IS_GNOME_DB_CONDITION(obj)       G_TYPE_CHECK_INSTANCE_TYPE (obj, gnome_db_condition_get_type ())
