@@ -77,13 +77,13 @@ typedef struct {
 	GnomeDbField        *dest_field;
 } GnomeDbCustomLayoutConnect;
 
-enum
+typedef enum
 {
 	GNOME_DB_CUSTOM_LAYOUT_XML_SAVE_ERROR,
 	GNOME_DB_CUSTOM_LAYOUT_XML_LOAD_ERROR,
 	GNOME_DB_CUSTOM_LAYOUT_GLADEXML_ERROR,
 	GNOME_DB_CUSTOM_LAYOUT_DATA_ERROR
-};
+} GnomeDbCustomLayoutError;
 
 /* error reporting */
 extern GQuark gnome_db_custom_layout_error_quark (void);
