@@ -28,7 +28,7 @@
 
 G_BEGIN_DECLS
 
-#define GNOME_DB_DATA_SET_TYPE          (gnome_db_data_set_get_type())
+#define GNOME_DB_TYPE_DATA_SET          (gnome_db_data_set_get_type())
 #define GNOME_DB_DATA_SET(obj)          G_TYPE_CHECK_INSTANCE_CAST (obj, gnome_db_data_set_get_type(), GnomeDbDataSet)
 #define GNOME_DB_DATA_SET_CLASS(klass)  G_TYPE_CHECK_CLASS_CAST (klass, gnome_db_data_set_get_type (), GnomeDbDataSetClass)
 #define IS_GNOME_DB_DATA_SET(obj)       G_TYPE_CHECK_INSTANCE_TYPE (obj, gnome_db_data_set_get_type ())
