@@ -139,7 +139,7 @@ GQuark gnome_db_database_error_quark (void)
  *
  * Returns: the type id
  */
-guint
+GType
 gnome_db_database_get_type (void)
 {
 	static GType type = 0;
@@ -164,8 +164,8 @@ gnome_db_database_get_type (void)
 			NULL
 		};
 
-		type = g_type_register_static (GNOME_DB_BASE_TYPE, "GnomeDbDatabase", &info, 0);
-		g_type_add_interface_static (type, GNOME_DB_XML_STORAGE_TYPE, &xml_storage_info);
+		type = g_type_register_static (GNOME_DB_TYPE_BASE, "GnomeDbDatabase", &info, 0);
+		g_type_add_interface_static (type, GNOME_DB_TYPE_XML_STORAGE, &xml_storage_info);
 	}
 	return type;
 }
@@ -392,7 +392,7 @@ gnome_db_database_new (GnomeDbDict *dict)
 
 	g_return_val_if_fail (!dict || IS_GNOME_DB_DICT (dict), NULL);
 
-	obj = g_object_new (GNOME_DB_DATABASE_TYPE, NULL);
+	obj = g_object_new (GNOME_DB_TYPE_DATABASE, NULL);
 	gnome_db_database = GNOME_DB_DATABASE (obj);
 
 	gnome_db_base_set_dict (GNOME_DB_BASE (gnome_db_database), ASSERT_DICT (dict));
