@@ -94,9 +94,10 @@ get_specs_database_creation (GnomeDbDsnConfigDruid *druid)
 		if (!druid->priv->client)
 			druid->priv->client = gda_client_new ();
 		
-		druid->priv->create_db_spec = gda_client_get_specs_to_create_database (druid->priv->client, 
-								gnome_db_provider_selector_get_selected_provider (
-								GNOME_DB_PROVIDER_SELECTOR (druid->priv->general_provider)));
+		druid->priv->create_db_spec = gda_client_get_provider_specs (druid->priv->client, 
+								    	     gnome_db_provider_selector_get_selected_provider (
+								             GNOME_DB_PROVIDER_SELECTOR (druid->priv->general_provider)),
+								             GDA_CLIENT_SPECS_CREATE_DATABASE);
 	}
 
 	return druid->priv->create_db_spec;
@@ -135,7 +136,7 @@ druid_finished_cb (GnomeDruidPage *druid_page, GtkWidget *druid_widget, GnomeDbD
 			return;
 
 		if (!gnome_db_data_set_is_valid (dset)) {
-			gnome_db_show_error (_("Missing mandatory informmation, to create database"));
+			gnome_db_show_error (NULL, _("Missing mandatory informmation, to create database"));
 			gnome_druid_set_page (GNOME_DRUID (druid), GNOME_DRUID_PAGE (druid->priv->newdb_page));
 			return;
 		}
@@ -175,7 +176,7 @@ druid_finished_cb (GnomeDruidPage *druid_page, GtkWidget *druid_widget, GnomeDbD
 			if (!allok) {
 				str = g_strdup_printf (_("Error creating database: %s"), 
 						       error && error->message ? error->message : _("Unknown error"));
-				gnome_db_show_error (str);
+				gnome_db_show_error (NULL, str);
 				g_free (str);
 
 				gnome_druid_set_page (GNOME_DRUID (druid), GNOME_DRUID_PAGE (druid->priv->newdb_page));
@@ -280,14 +281,14 @@ general_next_pressed_cb (GnomeDruidPage *druid_page,
 	/* check required fields have values */
 	name = gtk_entry_get_text (GTK_ENTRY (druid->priv->general_name));
 	if (!name || strlen (name) < 1) {
-		gnome_db_show_error (_("You must enter a name for the new data source"));
+		gnome_db_show_error (NULL, _("You must enter a name for the new data source"));
 		gtk_widget_grab_focus (druid->priv->general_name);
 		return TRUE;
 	}
 
 	for (i = 0; i < strlen (name); i++) {
 		if (!g_ascii_isalnum (name[i])) {
-			gnome_db_show_error (_("Data source names can only contain alphanumeric characters"));
+			gnome_db_show_error (NULL, _("Data source names can only contain alphanumeric characters"));
 			gtk_widget_grab_focus (druid->priv->general_name);
 			return TRUE;
 		}
@@ -296,18 +297,18 @@ general_next_pressed_cb (GnomeDruidPage *druid_page,
 	dsn_info = gda_config_find_data_source (name);
 	if (dsn_info != NULL) {
 		gda_data_source_info_free (dsn_info);
-		gnome_db_show_error (_("An existing data source is already registered under the same name"));
+		gnome_db_show_error (NULL, _("An existing data source is already registered under the same name"));
 		gtk_widget_grab_focus (druid->priv->general_name);
 		return TRUE;
 	}
 
 	for (i = 0; i < strlen (name); i++) {
 		if (g_ascii_isspace (name[i])) {
-			gnome_db_show_error (_("Data source names cannot contain spaces"));
+			gnome_db_show_error (NULL, _("Data source names cannot contain spaces"));
 			gtk_widget_grab_focus (druid->priv->general_name);
 			return TRUE;
 		} else if (!g_ascii_isalnum (name[i])) {
-			gnome_db_show_error (_("Data source names can only contain ASCII letters and numbers"));
+			gnome_db_show_error (NULL, _("Data source names can only contain ASCII letters and numbers"));
 			gtk_widget_grab_focus (druid->priv->general_name);
 			return TRUE;
 		}
@@ -316,7 +317,7 @@ general_next_pressed_cb (GnomeDruidPage *druid_page,
 	provider =  gnome_db_provider_selector_get_selected_provider (
 		GNOME_DB_PROVIDER_SELECTOR (druid->priv->general_provider));
 	if (!provider) {
-		gnome_db_show_error (_("You must select a provider for the new data source"));
+		gnome_db_show_error (NULL, _("You must select a provider for the new data source"));
 		gtk_widget_grab_focus (druid->priv->general_provider);
 		return TRUE;
 	}
@@ -326,7 +327,7 @@ general_next_pressed_cb (GnomeDruidPage *druid_page,
 	if (!prov_info) {
 		str = g_strdup_printf (_("Could not find provider %s in the current setup"),
 				       provider);
-		gnome_db_show_error (str);
+		gnome_db_show_error (NULL, str);
 		g_free (str);
 		gtk_widget_grab_focus (druid->priv->general_provider);
 		return TRUE;
@@ -367,9 +368,10 @@ choose_next_pressed_cb (GnomeDruidPage *druid_page,
 			if (!druid->priv->client)
 				druid->priv->client = gda_client_new ();
 			
-			str = gda_client_get_specs_to_create_database (druid->priv->client, 
-								       gnome_db_provider_selector_get_selected_provider (
-									       GNOME_DB_PROVIDER_SELECTOR (druid->priv->general_provider)));
+			str = gda_client_get_provider_specs (druid->priv->client, 
+						             gnome_db_provider_selector_get_selected_provider (
+						             GNOME_DB_PROVIDER_SELECTOR (druid->priv->general_provider)),
+						             GDA_CLIENT_SPECS_CREATE_DATABASE);
 			if (str) {
 				GnomeDbDataSet *dset;
 				GError *error = NULL;
