@@ -104,7 +104,7 @@ gnome_db_graphviz_get_type (void)
 			(GInstanceInitFunc) gnome_db_graphviz_init
 		};
 
-		type = g_type_register_static (GNOME_DB_BASE_TYPE, "GnomeDbGraphviz", &info, 0);
+		type = g_type_register_static (GNOME_DB_TYPE_BASE, "GnomeDbGraphviz", &info, 0);
 	}
 	return type;
 }
@@ -150,7 +150,7 @@ gnome_db_graphviz_new (GnomeDbDict *dict)
 
 	g_return_val_if_fail (!dict || IS_GNOME_DB_DICT (dict), NULL);
 
-	obj = g_object_new (GNOME_DB_GRAPHVIZ_TYPE, "dict", ASSERT_DICT (dict), NULL);
+	obj = g_object_new (GNOME_DB_TYPE_GRAPHVIZ, "dict", ASSERT_DICT (dict), NULL);
 	gnome_db_graphviz = GNOME_DB_GRAPHVIZ (obj);
 	gnome_db_base_set_id (GNOME_DB_BASE (gnome_db_graphviz), 0);
 
