@@ -103,7 +103,7 @@ gnome_db_layout_get_type (void)
                 };
 		
 		type = g_type_register_static (GTK_TYPE_VBOX, "GnomeDbLayout", &info, 0);
-		g_type_add_interface_static (type, GNOME_DB_DATA_WIDGET_TYPE, &work_widget_info);
+		g_type_add_interface_static (type, GNOME_DB_TYPE_DATA_WIDGET, &work_widget_info);
 	}
 
 	return type;
@@ -154,7 +154,7 @@ gnome_db_layout_new (GnomeDbCustomLayout *layout)
 
 	g_return_val_if_fail (layout && IS_GNOME_DB_CUSTOM_LAYOUT (layout), NULL);
 
-	obj = g_object_new (GNOME_DB_LAYOUT_TYPE, NULL);
+	obj = g_object_new (GNOME_DB_TYPE_LAYOUT, NULL);
 	wl = GNOME_DB_LAYOUT (obj);
 
 	wl->priv->layout = layout;
