@@ -63,7 +63,6 @@ static GnomeDbServerDataType *gnome_db_qf_value_get_data_type   (GnomeDbField *i
 
 /* Renderer interface */
 static void            gnome_db_qf_value_renderer_init      (GnomeDbRendererIface *iface);
-static GdaXqlItem     *gnome_db_qf_value_render_as_xql   (GnomeDbRenderer *iface, GnomeDbDataSet *context, GError **error);
 static gchar          *gnome_db_qf_value_render_as_sql   (GnomeDbRenderer *iface, GnomeDbDataSet *context, guint options, GError **error);
 static gchar          *gnome_db_qf_value_render_as_str   (GnomeDbRenderer *iface, GnomeDbDataSet *context);
 
@@ -119,15 +118,15 @@ enum
 struct _GnomeDbQfValuePrivate
 {
 	GnomeDbQuery          *query;
-	GdaValueType      gda_type;
+	GdaValueType           gda_type;
 	GnomeDbServerDataType *srv_type;
-	GdaValue         *value;        /* MUST either be NULL, or of type GDA_VALUE_NULL or 'type' */
-	GdaValue         *default_value;/* CAN either be NULL, or of any type */
-	gboolean          is_parameter;
-	gboolean          is_null_allowed;
+	GdaValue              *value;        /* MUST either be NULL, or of type GDA_VALUE_NULL or 'type' */
+	GdaValue              *default_value;/* CAN either be NULL, or of any type */
+	gboolean               is_parameter;
+	gboolean               is_null_allowed;
 	GnomeDbRefBase        *value_prov_ref; /* to a GnomeDbQfield of another query */
 
-	gchar            *plugin;       /* specific plugin to be used */
+	gchar                 *plugin;       /* specific plugin to be used */
 };
 
 
@@ -184,11 +183,11 @@ gnome_db_qf_value_get_type (void)
 		};
 		
 		
-		type = g_type_register_static (GNOME_DB_QFIELD_TYPE, "GnomeDbQfValue", &info, 0);
-		g_type_add_interface_static (type, GNOME_DB_XML_STORAGE_TYPE, &xml_storage_info);
-		g_type_add_interface_static (type, GNOME_DB_FIELD_TYPE, &field_info);
-		g_type_add_interface_static (type, GNOME_DB_RENDERER_TYPE, &renderer_info);
-		g_type_add_interface_static (type, GNOME_DB_REFERER_TYPE, &referer_info);
+		type = g_type_register_static (GNOME_DB_TYPE_QFIELD, "GnomeDbQfValue", &info, 0);
+		g_type_add_interface_static (type, GNOME_DB_TYPE_XML_STORAGE, &xml_storage_info);
+		g_type_add_interface_static (type, GNOME_DB_TYPE_FIELD, &field_info);
+		g_type_add_interface_static (type, GNOME_DB_TYPE_RENDERER, &renderer_info);
+		g_type_add_interface_static (type, GNOME_DB_TYPE_REFERER, &referer_info);
 	}
 	return type;
 }
@@ -211,7 +210,6 @@ gnome_db_qf_value_field_init (GnomeDbFieldIface *iface)
 static void
 gnome_db_qf_value_renderer_init (GnomeDbRendererIface *iface)
 {
-	iface->render_as_xql = gnome_db_qf_value_render_as_xql;
 	iface->render_as_sql = gnome_db_qf_value_render_as_sql;
 	iface->render_as_str = gnome_db_qf_value_render_as_str;
 	iface->is_valid = NULL;
@@ -309,7 +307,7 @@ gnome_db_qf_value_new (GnomeDbQuery *query, GnomeDbServerDataType *type)
 	g_return_val_if_fail (type && IS_GNOME_DB_SERVER_DATA_TYPE (type), NULL);
 	dict = gnome_db_base_get_dict (GNOME_DB_BASE (query));
 
-	obj = g_object_new (GNOME_DB_QF_VALUE_TYPE, "dict", dict, NULL);
+	obj = g_object_new (GNOME_DB_TYPE_QF_VALUE, "dict", dict, NULL);
 	gnome_db_qf_value = GNOME_DB_QF_VALUE (obj);
 	g_object_get (G_OBJECT (query), "field_serial", &id, NULL);
 	gnome_db_base_set_id (GNOME_DB_BASE (gnome_db_qf_value), id);
@@ -876,7 +874,7 @@ gnome_db_qf_value_restrict_with_field (GnomeDbQfValue *field, GnomeDbQfield *pro
 		}
 		
 		field->priv->value_prov_ref = GNOME_DB_REF_BASE (gnome_db_ref_base_new (gnome_db_base_get_dict (GNOME_DB_BASE (field))));
-		gnome_db_ref_base_set_ref_object_type (field->priv->value_prov_ref, GNOME_DB_BASE (provider), GNOME_DB_FIELD_TYPE);
+		gnome_db_ref_base_set_ref_object_type (field->priv->value_prov_ref, GNOME_DB_BASE (provider), GNOME_DB_TYPE_FIELD);
 	}
 	
 	return TRUE;
@@ -906,7 +904,7 @@ gnome_db_qf_value_restrict_with_field_xml (GnomeDbQfValue *field, const gchar *p
 	if (prov_xml_id) {
 		/* No test possible, really */
 		field->priv->value_prov_ref = GNOME_DB_REF_BASE (gnome_db_ref_base_new (gnome_db_base_get_dict (GNOME_DB_BASE (field))));
-		gnome_db_ref_base_set_ref_name (field->priv->value_prov_ref, GNOME_DB_FIELD_TYPE, REFERENCE_BY_XML_ID,
+		gnome_db_ref_base_set_ref_name (field->priv->value_prov_ref, GNOME_DB_TYPE_FIELD, REFERENCE_BY_XML_ID,
 						prov_xml_id);
 	}
 
@@ -1304,17 +1302,6 @@ gnome_db_qf_value_load_from_xml (GnomeDbXmlStorage *iface, xmlNodePtr node, GErr
 /*
  * GnomeDbRenderer interface implementation
  */
-static GdaXqlItem *
-gnome_db_qf_value_render_as_xql (GnomeDbRenderer *iface, GnomeDbDataSet *context, GError **error)
-{
-	GdaXqlItem *node = NULL;
-
-	g_return_val_if_fail (iface && IS_GNOME_DB_QF_VALUE (iface), NULL);
-	g_return_val_if_fail (GNOME_DB_QF_VALUE (iface)->priv, NULL);
-	
-	TO_IMPLEMENT;
-	return node;
-}
 
 static gboolean
 gnome_db_qf_value_render_find_value (GnomeDbQfValue *field, GnomeDbDataSet *context, 
