@@ -26,6 +26,7 @@
 #include "marshal.h"
 #include <libgda/libgda.h>
 #include <string.h>
+#include "utility.h"
 
 /* 
  * Main static functions 
@@ -77,7 +78,7 @@ enum
 struct _GnomeDbServerAggregatePrivate
 {
 	GnomeDbServer         *srv;
-	gchar            *objectid;       /* unique id for the aggregate */
+	gchar                 *objectid;       /* unique id for the aggregate */
 	GnomeDbServerDataType *result_type;
 	GnomeDbServerDataType *arg_type;
 };
@@ -117,8 +118,8 @@ gnome_db_server_aggregate_get_type (void)
 			NULL
 		};
 		
-		type = g_type_register_static (GNOME_DB_BASE_TYPE, "GnomeDbServerAggregate", &info, 0);
-		g_type_add_interface_static (type, GNOME_DB_XML_STORAGE_TYPE, &xml_storage_info);
+		type = g_type_register_static (GNOME_DB_TYPE_BASE, "GnomeDbServerAggregate", &info, 0);
+		g_type_add_interface_static (type, GNOME_DB_TYPE_XML_STORAGE, &xml_storage_info);
 	}
 	return type;
 }
@@ -192,7 +193,7 @@ gnome_db_server_aggregate_new (GnomeDbServer *srv)
 
 	g_return_val_if_fail (srv && GNOME_DB_SERVER (srv), NULL);
 
-	obj = g_object_new (GNOME_DB_SERVER_AGGREGATE_TYPE, "dict",
+	obj = g_object_new (GNOME_DB_TYPE_SERVER_AGGREGATE, "dict",
 			    gnome_db_server_get_dict (srv), NULL);
 	gnome_db_server_aggregate = GNOME_DB_SERVER_AGGREGATE (obj);
 	gnome_db_base_set_id (GNOME_DB_BASE (gnome_db_server_aggregate), 0);
@@ -327,7 +328,7 @@ gnome_db_aggregate_get_xml_id (GnomeDbXmlStorage *iface)
 	g_return_val_if_fail (iface && IS_GNOME_DB_SERVER_AGGREGATE (iface), NULL);
 	g_return_val_if_fail (GNOME_DB_SERVER_AGGREGATE (iface)->priv, NULL);
 
-	return g_strdup_printf ("AG%s", GNOME_DB_SERVER_AGGREGATE (iface)->priv->objectid);
+	return g_strconcat ("AG", GNOME_DB_SERVER_AGGREGATE (iface)->priv->objectid, NULL);
 }
 
 static xmlNodePtr
@@ -506,7 +507,8 @@ gnome_db_server_aggregate_set_dbms_id (GnomeDbServerAggregate *agg, const gchar
 
 	if (agg->priv->objectid)
 		g_free (agg->priv->objectid);
-	agg->priv->objectid = g_strdup (id);
+
+	agg->priv->objectid = utility_build_encoded_id (NULL, id);
 }
 
 
@@ -518,13 +520,13 @@ gnome_db_server_aggregate_set_dbms_id (GnomeDbServerAggregate *agg, const gchar
  *
  * Returns: the aggregate's id
  */
-const gchar *
+gchar *
 gnome_db_server_aggregate_get_dbms_id (GnomeDbServerAggregate *agg)
 {
 	g_return_val_if_fail (agg && IS_GNOME_DB_SERVER_AGGREGATE (agg), NULL);
 	g_return_val_if_fail (agg->priv, NULL);
 
-	return agg->priv->objectid;
+	return utility_build_decoded_id (NULL, agg->priv->objectid);
 }
 
 
