@@ -26,6 +26,7 @@
 #include "marshal.h"
 #include <libgda/libgda.h>
 #include <string.h>
+#include "utility.h"
 
 /* 
  * Main static functions 
@@ -77,9 +78,9 @@ enum
 struct _GnomeDbServerFunctionPrivate
 {
 	GnomeDbServer         *srv;
-	gchar            *objectid;       /* unique id for the function */
+	gchar                 *objectid;       /* unique id for the function */
 	GnomeDbServerDataType *result_type;
-	GSList           *arg_types;           /* list of GnomeDbServerDataType pointers */
+	GSList                *arg_types;      /* list of GnomeDbServerDataType pointers */
 };
 
 
@@ -117,8 +118,8 @@ gnome_db_server_function_get_type (void)
 			NULL
 		};
 		
-		type = g_type_register_static (GNOME_DB_BASE_TYPE, "GnomeDbServerFunction", &info, 0);
-		g_type_add_interface_static (type, GNOME_DB_XML_STORAGE_TYPE, &xml_storage_info);
+		type = g_type_register_static (GNOME_DB_TYPE_BASE, "GnomeDbServerFunction", &info, 0);
+		g_type_add_interface_static (type, GNOME_DB_TYPE_XML_STORAGE, &xml_storage_info);
 	}
 	return type;
 }
@@ -192,7 +193,7 @@ gnome_db_server_function_new (GnomeDbServer *srv)
 
 	g_return_val_if_fail (srv && GNOME_DB_SERVER (srv), NULL);
 
-	obj = g_object_new (GNOME_DB_SERVER_FUNCTION_TYPE, "dict",
+	obj = g_object_new (GNOME_DB_TYPE_SERVER_FUNCTION, "dict",
 			    gnome_db_server_get_dict (srv), NULL);
 	gnome_db_server_function = GNOME_DB_SERVER_FUNCTION (obj);
 	gnome_db_base_set_id (GNOME_DB_BASE (gnome_db_server_function), 0);
@@ -337,7 +338,7 @@ gnome_db_function_get_xml_id (GnomeDbXmlStorage *iface)
 	g_return_val_if_fail (iface && IS_GNOME_DB_SERVER_FUNCTION (iface), NULL);
 	g_return_val_if_fail (GNOME_DB_SERVER_FUNCTION (iface)->priv, NULL);
 
-	return g_strdup_printf ("PR%s", GNOME_DB_SERVER_FUNCTION (iface)->priv->objectid);
+	return g_strconcat ("PR", GNOME_DB_SERVER_FUNCTION (iface)->priv->objectid, NULL);
 }
 
 static xmlNodePtr
@@ -510,7 +511,8 @@ gnome_db_server_function_set_dbms_id (GnomeDbServerFunction *func, const gchar *
 
 	if (func->priv->objectid)
 		g_free (func->priv->objectid);
-	func->priv->objectid = g_strdup (id);
+
+	func->priv->objectid = utility_build_encoded_id (NULL, id);
 }
 
 
@@ -520,15 +522,15 @@ gnome_db_server_function_set_dbms_id (GnomeDbServerFunction *func, const gchar *
  *
  * Get the DBMS identifier of the function
  *
- * Returns: the function's id
+ * Returns: a new string with the function's id
  */
-const gchar *
+gchar *
 gnome_db_server_function_get_dbms_id (GnomeDbServerFunction *func)
 {
 	g_return_val_if_fail (func && IS_GNOME_DB_SERVER_FUNCTION (func), NULL);
 	g_return_val_if_fail (func->priv, NULL);
 
-	return func->priv->objectid;
+	return utility_build_decoded_id (NULL, func->priv->objectid);
 }
 
 
