@@ -439,7 +439,7 @@ item_event (GnomeDbCanvasItem *citem, GdkEvent *event, gpointer data)
 					(class->extra_event) (citem, GDK_LEAVE_NOTIFY);
 
 				ci = gnome_canvas_item_new (GNOME_CANVAS_GROUP (citem),
-							    GNOME_DB_CANVAS_CURSOR_TYPE,
+							    GNOME_DB_TYPE_CANVAS_CURSOR,
 							    "x", ((GdkEventButton *) event)->x - 5.,
 							    "y", ((GdkEventButton *) event)->y - 5.,
 							    "fill_color", "white",
@@ -560,7 +560,7 @@ static gboolean display_tip_timeout (GnomeDbCanvasItem *citem)
 		y = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (citem), "mousey"));
 		
 		tip = gnome_canvas_item_new (gnome_canvas_root (GNOME_CANVAS_ITEM (citem)->canvas),
-					     GNOME_DB_CANVAS_TIP_TYPE,
+					     GNOME_DB_TYPE_CANVAS_TIP,
 					     "x", x+7.,
 					     "y", y+3.,
 					     "tip_text", citem->priv->tooltip_text,
