@@ -89,7 +89,7 @@ gnome_db_canvas_text_get_type (void)
 			(GInstanceInitFunc) gnome_db_canvas_text_init
 		};		
 
-		type = g_type_register_static (GNOME_DB_CANVAS_ITEM_TYPE, "GnomeDbCanvasText", &info, 0);
+		type = g_type_register_static (GNOME_DB_TYPE_CANVAS_ITEM, "GnomeDbCanvasText", &info, 0);
 	}
 
 	return type;
