@@ -65,7 +65,7 @@ struct  _GnomeDbHandlerStringPriv {
 	gchar          *detailled_descr;
 	guint           nb_gda_types;
 	GdaValueType   *valid_gda_types;
-	GnomeDbServer       *srv;
+	GnomeDbServer  *srv;
 };
 
 /* get a pointer to the parents to be able to call their destructor */
@@ -95,8 +95,8 @@ gnome_db_handler_string_get_type (void)
 			NULL
 		};
 
-		type = g_type_register_static (GNOME_DB_BASE_TYPE, "GnomeDbHandlerString", &info, 0);
-		g_type_add_interface_static (type, GNOME_DB_DATA_HANDLER_TYPE, &data_entry_info);
+		type = g_type_register_static (GNOME_DB_TYPE_BASE, "GnomeDbHandlerString", &info, 0);
+		g_type_add_interface_static (type, GNOME_DB_TYPE_DATA_HANDLER, &data_entry_info);
 	}
 	return type;
 }
@@ -191,7 +191,7 @@ gnome_db_handler_string_new (GnomeDbServer *srv)
 	GnomeDbHandlerString *hdl;
 
 	g_return_val_if_fail (srv && IS_GNOME_DB_SERVER (srv), NULL);
-	obj = g_object_new (GNOME_DB_HANDLER_STRING_TYPE, NULL);
+	obj = g_object_new (GNOME_DB_TYPE_HANDLER_STRING, NULL);
 	hdl = GNOME_DB_HANDLER_STRING (obj);
 
 	g_object_add_weak_pointer (G_OBJECT (srv), (gpointer *) &(hdl->priv->srv));
@@ -239,7 +239,7 @@ gnome_db_handler_string_get_sql_from_value (GnomeDbDataHandler *iface, const Gda
 	hdl = GNOME_DB_HANDLER_STRING (iface);
 	g_return_val_if_fail (hdl->priv, NULL);
 
-	str = gnome_db_server_stringify_value (hdl->priv->srv, value);
+	str = gda_value_stringify (value);
 	if (str) {
 		str2 = gnome_db_server_escape_chars (hdl->priv->srv, str);
 		retval = g_strdup_printf ("'%s'", str2);
@@ -261,7 +261,7 @@ gnome_db_handler_string_get_str_from_value (GnomeDbDataHandler *iface, const Gda
 	hdl = GNOME_DB_HANDLER_STRING (iface);
 	g_return_val_if_fail (hdl->priv, NULL);
 
-	return gnome_db_server_stringify_value (hdl->priv->srv, value);
+	return gda_value_stringify (value);
 }
 
 static GdaValue *
